@@ -18,8 +18,8 @@ usage:	ucstoany.pl [-f][+u|-u]|[+f[+g|-g]] [+o|-o OUTPUT]
 +f	Fillout mode - encode with unicodes, output characters
 	with unicode FFFF as the default character.
   +g	Exchange the characters in range 00...1F with these at
-        C0...DF. Default for 256 character fonts not starting
-	with FFFD.
+	C0...DF. Default for 8-pixel wide 256-character fonts
+	not starting with FFFD.
   -g	Do not exchange. Default for all other fonts.
 
 +o	Output to INPUT-REGISTRY-ENCODING (using the same name
@@ -31,7 +31,7 @@ usage:	ucstoany.pl [-f][+u|-u]|[+f[+g|-g]] [+o|-o OUTPUT]
 -b	Use text mode for output. This is the default.
 
 +[CHAR]	Set the default character to CHAR. If no CHAR is
-        specified, the one from INPUT is used.
+	specified, the one from INPUT is used.
 
 --	Terminate the option list.
 
@@ -49,8 +49,6 @@ unicode and fillout modes, 46 (period) for index mode.
 
 Any options not specified in the above order are treated as
 non-option arguments.
-
-Warning: this program is not compatible with ucs2any.pl!
 EOT
 	exit 0;
 }
@@ -58,7 +56,7 @@ EOT
 if($ARGV[0] eq "--version")
 {
 print STDERR <<EOT;
-ucstoany.pl 0.0.5, Copyright (C) 2004 Dimitar Toshkov Zhekov
+ucstoany.pl 0.1.0, Copyright (C) 2005 Dimitar Toshkov Zhekov
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -70,8 +68,6 @@ but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
-This program is not based on ucs2any.pl or any other program.
-
 Report bugs to jimmy\@is-vn.bg
 EOT
 	exit 0;
@@ -162,13 +158,14 @@ while(<BDF>)
 	if(/^STARTCHAR\s+(.+)$/) { $startchar = $1; }
 	elsif(/^ENCODING\s+(.+)$/) { $encoding = $1; }
 	$buffer .= $_;
-	if(/^ENDCHAR/)
+	if(/^ENDCHAR$/)
 	{
 		$startchar ne "" || die("$0: $ARGV[0]: ENDCHAR without STARTCHAR\n");
 		$encoding ne "" || die("$0: $ARGV[0]: no ENCODING for $startchar\n");
 		$bitmap{$encoding} = $buffer;
 		$buffer = $startchar = $encoding = "";
 	}
+	elsif(!defined($exchange) && /^BBX\s+([0-9]+)/ && $1 != 8) { $exchange = 0; }
 }
 
 close BDF;
@@ -219,8 +216,17 @@ $header =~ s/^(CHARSET_ENCODING\s).*$/$1"$ARGV[2]"/m || die("$0: $output: unable
 $header =~ s/^(DEFAULT_CHAR\s).*$/$1$default/m || die("$0: $output: unable to change DEFAULT_CHAR\n");
 $header =~ s/^(CHARS\s).*$/$1$chars/m || die("$0: $output: unable to change CHARS\n");
 
+sub int { $int = $!; }
+sub bye
+{
+	close OUT;
+	$output ne "-" && unlink($output) != 1 && print STDERR "$0: $output: $!\n";
+	die("@_");
+}
+
 open(OUT, ">$output") || die("$0: $output: $!\n");
-if($binary) { binmode(OUT) || die("$0: $output: $!\n"); }
+$SIG{INT} = 'int';
+if($binary) { binmode(OUT) || bye("$0: $output: $!\n"); }
 print OUT $header;
 
 for($index = 0; $index < @unimap; $index++)
@@ -228,9 +234,10 @@ for($index = 0; $index < @unimap; $index++)
 	$_ = $unimap[$index];
 	$encoding = $index >= $control ? $_ : $index;
 	if($_ == 65535) { if($control) { next; } else { $_ = $default ; } }
-	$bitmap{$_} =~ s/^(ENCODING\s).*$/$1$encoding/m || die("$0: $output: unable to change encoding for $_\n");
+	$bitmap{$_} =~ s/^(ENCODING\s).*$/$1$encoding/m || bye("$0: $output: unable to change encoding for $_\n");
 	print OUT $bitmap{$_};
 }
 
 print OUT $buffer;
-close OUT;
+close OUT || bye("$0: $output: $!\n");
+defined($int) && bye("$0: $int\n");
